@@ -53,8 +53,9 @@ package_deprecation_message = (
     "https://github.com/googleapis/python-dialogflow/issues."
 )
 
-warnings.warn(package_deprecation_message, DeprecationWarning)
-
+raise RuntimeError(
+    package_deprecation_message
+)
 
 class EnvironmentsClient(environments_client.EnvironmentsClient):
     __doc__ = environments_client.EnvironmentsClient.__doc__
