@@ -38,6 +38,8 @@ from dialogflow_v2beta1.proto import agent_pb2
 from dialogflow_v2beta1.proto import agent_pb2_grpc
 from dialogflow_v2beta1.proto import context_pb2
 from dialogflow_v2beta1.proto import context_pb2_grpc
+from dialogflow_v2beta1.proto import environment_pb2
+from dialogflow_v2beta1.proto import environment_pb2_grpc
 from dialogflow_v2beta1.proto import validation_result_pb2
 from google.longrunning import operations_pb2
 from google.protobuf import empty_pb2
@@ -49,24 +51,7 @@ _GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution("dialogflow").version
 
 
 class ContextsClient(object):
-    """
-    A context represents additional information included with user input or
-    with an intent returned by the Dialogflow API. Contexts are helpful for
-    differentiating user input which may be vague or have a different
-    meaning depending on additional details from your application such as
-    user setting and preferences, previous user input, where the user is in
-    your application, geographic location, and so on.
-
-    You can include contexts as input parameters of a ``DetectIntent`` (or
-    ``StreamingDetectIntent``) request, or as output contexts included in
-    the returned intent. Contexts expire when an intent is matched, after
-    the number of ``DetectIntent`` requests specified by the
-    ``lifespan_count`` parameter, or after 20 minutes if no intents are
-    matched for a ``DetectIntent`` request.
-
-    For more information about contexts, see the `Dialogflow
-    documentation <https://cloud.google.com/dialogflow/docs/contexts-overview>`__.
-    """
+    """Service for managing ``Contexts``."""
 
     SERVICE_ADDRESS = "dialogflow.googleapis.com:443"
     """The default address of the service."""
@@ -266,7 +251,8 @@ class ContextsClient(object):
             >>>
             >>> client = dialogflow_v2beta1.ContextsClient()
             >>>
-            >>> parent = client.session_path('[PROJECT]', '[SESSION]')
+            >>> # TODO: Initialize `parent`:
+            >>> parent = ''
             >>>
             >>> # Iterate over all results
             >>> for element in client.list_contexts(parent):
@@ -371,7 +357,8 @@ class ContextsClient(object):
             >>>
             >>> client = dialogflow_v2beta1.ContextsClient()
             >>>
-            >>> name = client.context_path('[PROJECT]', '[SESSION]', '[CONTEXT]')
+            >>> # TODO: Initialize `name`:
+            >>> name = ''
             >>>
             >>> response = client.get_context(name)
 
@@ -449,7 +436,8 @@ class ContextsClient(object):
             >>>
             >>> client = dialogflow_v2beta1.ContextsClient()
             >>>
-            >>> parent = client.session_path('[PROJECT]', '[SESSION]')
+            >>> # TODO: Initialize `parent`:
+            >>> parent = ''
             >>>
             >>> # TODO: Initialize `context`:
             >>> context = {}
@@ -610,7 +598,8 @@ class ContextsClient(object):
             >>>
             >>> client = dialogflow_v2beta1.ContextsClient()
             >>>
-            >>> name = client.context_path('[PROJECT]', '[SESSION]', '[CONTEXT]')
+            >>> # TODO: Initialize `name`:
+            >>> name = ''
             >>>
             >>> client.delete_context(name)
 
@@ -682,13 +671,14 @@ class ContextsClient(object):
             >>>
             >>> client = dialogflow_v2beta1.ContextsClient()
             >>>
-            >>> parent = client.session_path('[PROJECT]', '[SESSION]')
+            >>> # TODO: Initialize `parent`:
+            >>> parent = ''
             >>>
             >>> client.delete_all_contexts(parent)
 
         Args:
-            parent (str): Required. The name of the session to delete all contexts from. Format:
-                ``projects/<Project ID>/agent/sessions/<Session ID>`` or
+            parent (str): Required. The name of the session to delete all contexts from.
+                Format: ``projects/<Project ID>/agent/sessions/<Session ID>`` or
                 ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session ID>``.
                 If ``Environment ID`` is not specified we assume default 'draft'
                 environment. If ``User ID`` is not specified, we assume default '-'
